@@ -17,10 +17,11 @@ _DEFAULTS = {
     'CAS_GATEWAY': False,
     'CAS_PROXY_CALLBACK': None,
     'CAS_RESPONSE_CALLBACKS': None,
-    'CAS_CUSTOM_FORBIDDEN':None,
+    'CAS_CUSTOM_FORBIDDEN': None,
     'CAS_LOGOUT_REQUEST_ALLOWED': (),
     'CAS_USER_CREATION': True,
-    'CAS_USERNAME_FORMAT': None
+    'CAS_USER_CREATION_CALLBACK': None,
+    'CAS_USERNAME_FORMAT': None,
 }
 
 for key, value in iteritems(_DEFAULTS):
