@@ -6,14 +6,24 @@ from six.moves.urllib_parse import urlencode
 from django.conf import settings
 from django.contrib.auth import REDIRECT_FIELD_NAME
 from django.contrib.auth import logout as do_logout
-from django.contrib.auth.views import login, logout
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.http import HttpResponseRedirect, HttpResponseForbidden
 from django.core.exceptions import ImproperlyConfigured
 
+try:
+    from django.contrib.auth.views import login, logout
+except ImportError:
+    from django.contrib.auth import login, logout
+
+try:
+    from django.utils.deprecation import MiddlewareMixin
+except ImportError:
+    MiddlewareMixin = object
+
 from django_cas.exceptions import CasTicketException
 from django_cas.views import login as cas_login, logout as cas_logout
 
+
 __all__ = ['CASMiddleware']
 
 
@@ -43,14 +53,16 @@ def cas_request_logout_allowed(request):
     return False
 
 
-class CASMiddleware(object):
+class CASMiddleware(MiddlewareMixin):
     """Middleware that allows CAS authentication on admin pages"""
 
+    def _is_an_admin_view(self, view_func):
+        return view_func.__module__.startswith('django.contrib.admin.')
+
     def process_request(self, request):
         """Checks that the authentication middleware is installed"""
-
         error = ("The Django CAS middleware requires authentication "
-                 "middleware to be installed. Edit your MIDDLEWARE_CLASSES "
+                 "middleware to be installed. Edit your MIDDLEWARE "
                  "setting to insert 'django.contrib.auth.middleware."
                  "AuthenticationMiddleware'.")
         assert hasattr(request, 'user'), error
@@ -71,13 +83,15 @@ class CASMiddleware(object):
         elif view_func == logout:
             return cas_logout(request, *view_args, **view_kwargs)
 
-        if settings.CAS_ADMIN_PREFIX:
-            if not request.path.startswith(settings.CAS_ADMIN_PREFIX):
-                return None
-        elif not view_func.__module__.startswith('django.contrib.admin.'):
+        # for all view modules except django admin. by default, we redirect to
+        # cas for all admin views
+        # for all other views, we treats the request with respect of views
+        # configuration
+        if not (self._is_an_admin_view(view_func) and settings.CAS_ADMIN_AUTH):
             return None
 
-        if request.user.is_authenticated():
+
+        if request.user.is_authenticated:
             if request.user.is_staff:
                 return None
             else:
@@ -85,7 +99,9 @@ class CASMiddleware(object):
                          'privileges.</p>')
                 return HttpResponseForbidden(error)
         params = urlencode({REDIRECT_FIELD_NAME: request.get_full_path()})
-        return HttpResponseRedirect(reverse(cas_login) + '?' + params)
+        return HttpResponseRedirect(
+            '{}?{}'.format(reverse('django_cas:login'), params)
+        )
 
     def process_exception(self, request, exception):
         """When we get a CasTicketException, that is probably caused by the ticket timing out.
@@ -106,4 +122,4 @@ class ProxyMiddleware(object):
         if not proxy:
             raise ImproperlyConfigured('To use Proxy Middleware you must set a PROXY_DOMAIN setting.')
         else:
-            request.META['HTTP_HOST'] = proxy
\ No newline at end of file
+            request.META['HTTP_HOST'] = proxy
